@@ -12,7 +12,6 @@
 
 namespace Bugzilla
 {
-
 class ConnectionDouble : public Connection
 {
 public:
@@ -23,40 +22,32 @@ public:
         Q_UNREACHABLE();
     }
 
-    virtual APIJob *get(const QString &path,
-                        const QUrlQuery &query = QUrlQuery()) const override
+    virtual APIJob *get(const QString &path, const QUrlQuery &query = QUrlQuery()) const override
     {
         Q_UNUSED(path)
         Q_UNUSED(query)
-        Q_ASSERT_X(false, "get",
-                   qUtf8Printable(QStringLiteral("unmapped: %1; %2").arg(path, query.toString())));
+        Q_ASSERT_X(false, "get", qUtf8Printable(QStringLiteral("unmapped: %1; %2").arg(path, query.toString())));
         return nullptr;
     }
 
-    virtual APIJob *post(const QString &path,
-                         const QByteArray &data,
-                         const QUrlQuery &query = QUrlQuery()) const override
+    virtual APIJob *post(const QString &path, const QByteArray &data, const QUrlQuery &query = QUrlQuery()) const override
     {
         Q_UNUSED(query);
         if (path == "/bug/1/attachment") {
             QJsonParseError error;
             QJsonDocument::fromJson(data, &error);
             Q_ASSERT(error.error == QJsonParseError::NoError);
-            return new JobDouble { QFINDTESTDATA("data/attachment.new.json") };
+            return new JobDouble{QFINDTESTDATA("data/attachment.new.json")};
         }
-        Q_ASSERT_X(false, "post",
-                   qUtf8Printable(QStringLiteral("unmapped: %1; %2").arg(path, query.toString())));
+        Q_ASSERT_X(false, "post", qUtf8Printable(QStringLiteral("unmapped: %1; %2").arg(path, query.toString())));
         return nullptr;
     }
 
-    virtual APIJob *put(const QString &path,
-                        const QByteArray &,
-                        const QUrlQuery &query = QUrlQuery()) const override
+    virtual APIJob *put(const QString &path, const QByteArray &, const QUrlQuery &query = QUrlQuery()) const override
     {
         Q_UNUSED(path)
         Q_UNUSED(query)
-        Q_ASSERT_X(false, "put",
-                   qUtf8Printable(QStringLiteral("unmapped: %1; %2").arg(path, query.toString())));
+        Q_ASSERT_X(false, "put", qUtf8Printable(QStringLiteral("unmapped: %1; %2").arg(path, query.toString())));
         return nullptr;
     }
 };
@@ -75,11 +66,11 @@ private Q_SLOTS:
     {
         Bugzilla::AttachmentClient c;
         NewAttachment attachment;
-        attachment.ids = { 1 };
+        attachment.ids = {1};
         attachment.data = "123";
         attachment.file_name = "filename123";
         attachment.summary = "summary123";
-//        attachment.content_type = "123";
+        //        attachment.content_type = "123";
         attachment.comment = "comment123";
         attachment.is_patch = true;
         attachment.is_private = false;
